==> kubernetes-model-1.0.40-sources.jar: annotations/io/fabric8/kubernetes/api/model/IDRangeBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class IDRangeBuilder extends IDRangeFluentImpl<IDRangeBuilder> implements VisitableBuilder<IDRange,IDRangeBuilder>{

     IDRangeFluent<?> fluent;
public IDRangeBuilder(){
    this(new IDRange());
}
public IDRangeBuilder( IDRangeFluent<?> fluent ){
    this(fluent, new IDRange());
}
public IDRangeBuilder( IDRangeFluent<?> fluent , IDRange instance ){
    this.fluent = fluent; fluent.withMax(instance.getMax()); fluent.withMin(instance.getMin()); 
}
public IDRangeBuilder( IDRange instance ){
    this.fluent = this; this.withMax(instance.getMax()); this.withMin(instance.getMin()); 
}

public EditableIDRange build(){
    EditableIDRange buildable = new EditableIDRange(fluent.getMax(),fluent.getMin());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
IDRangeBuilder that = (IDRangeBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/kubernetes/api/model/IDRangeBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class IDRangeBuilder extends IDRangeFluentImpl<IDRangeBuilder> implements VisitableBuilder<IDRange,IDRangeBuilder>{

     IDRangeFluent<?> fluent;
public IDRangeBuilder(){
    this(new IDRange());
}
public IDRangeBuilder( IDRangeFluent<?> fluent ){
    this(fluent, new IDRange());
}
public IDRangeBuilder( IDRangeFluent<?> fluent , IDRange instance ){
    this.fluent = fluent; fluent.withMax(instance.getMax()); fluent.withMin(instance.getMin()); 
}
public IDRangeBuilder( IDRange instance ){
    this.fluent = this; this.withMax(instance.getMax()); this.withMin(instance.getMin()); 
}

public IDRange build(){
    IDRange buildable = new IDRange(fluent.getMax(),fluent.getMin());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
IDRangeBuilder that = (IDRangeBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    Validator validator = null;
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    } catch(ValidationException e) {
        //ignore
        return;
    }

    Set<ConstraintViolation<T>> violations = validator.validate(item);
    if (!violations.isEmpty()) {
        throw new ConstraintViolationException(violations);
    }
}

}
